@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "19-Nov-25"
+#define SND_DATE "1-Jan-26"
 #ifndef SND_VERSION
-#define SND_VERSION "25.9"
+#define SND_VERSION "26.0"
 #endif
-#define SND_MAJOR_VERSION "25"
-#define SND_MINOR_VERSION "9"
+#define SND_MAJOR_VERSION "26"
+#define SND_MINOR_VERSION "0"
 
 #endif
